pub struct DependencyResolutionOptions {
pub scope_override: Option<Scope>,
pub force: bool,
pub yes: bool,
pub all_optional: bool,
pub build_type: Option<String>,
pub quiet: bool,
}Expand description
Options for resolving a dependency graph without installing packages.
Fields
scope_override: Option<Scope>Optional scope to use when resolving dependencies.
force: boolInclude packages even when they appear to be installed already.
yes: boolAutomatically answer yes to resolver prompts.
all_optional: boolAccept all optional dependencies.
build_type: Option<String>Build type used for selecting typed build dependencies.
quiet: boolSuppress non-essential resolver output.