pub struct ResolvedPackage {
pub package: Package,
pub version: String,
pub sharable_manifest: Option<SharableInstallManifest>,
pub source_path: PathBuf,
pub registry_handle: Option<String>,
pub repo_type: Option<String>,
pub git_sha: Option<String>,
}Expand description
Result of resolving a single package source.
Fields
package: PackageParsed package metadata.
version: StringResolved package version.
sharable_manifest: Option<SharableInstallManifest>Portable manifest information suitable for lockfiles.
source_path: PathBufLocal path to the resolved package definition.
registry_handle: Option<String>Registry handle, when the source came from a registry.
repo_type: Option<String>Registry repository type (official, community, etc.).
git_sha: Option<String>Git commit SHA, when the source came from a git repository.