pub struct SourceInstallOptions {
pub repo: Option<String>,
pub force: bool,
pub all_optional: bool,
pub yes: bool,
pub scope_override: Option<Scope>,
pub save: bool,
pub build_type: Option<String>,
pub dry_run: bool,
pub build: bool,
pub frozen: bool,
}Expand description
Options for installing one or more package source strings.
Fields
repo: Option<String>Optional git repository spec for zoi install --repo.
force: boolForce reinstalling packages that are already installed.
all_optional: boolAccept all optional dependencies.
yes: boolAutomatically answer yes to prompts.
scope_override: Option<Scope>Optional installation scope override.
save: boolSave requested packages to the current project’s zoi.yaml.
build_type: Option<String>Build type to use when building from source.
dry_run: boolPrint the install plan without performing the installation.
build: boolForce building from source even when a prebuilt archive is available.
frozen: boolEnforce the current zoi.lock exactly for project installs.