pub fn commit(transaction_id: &str) -> Result<(), Error>Expand description
Commits a transaction by moving it to the history directory.
Errors
Returns an error if the transaction directory cannot be accessed or if the log file cannot be moved to the history directory.